@@ -404,6 +404,9 @@ OBJECT *dest_index, OBJECT *recs, OBJECT *inners, OBJECT enclose)
 	  { if( *inners == nilobj )  New(*inners, ACAT);
 	    Link(*inners, z);
 	  }
+	  Child(tmp, Down(z));
+	  debug2(DGA, D, "SizeGalley %s%s", actual(tmp) == NULL ? "null" :
+	    SymName(actual(tmp)), after_target ? " (after_target)" : "");
 	  break;
 
 		
